<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es" sourcelanguage="en">
<context>
    <name>ArrowToolOptionsBox</name>
    <message>
        <source>Pick:</source>
        <translation>Escoger:</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Posición</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>Z:</source>
        <translation>Z:</translation>
    </message>
    <message>
        <source>SO:</source>
        <translation>Orden:</translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation>Rotación</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Escala</translation>
    </message>
    <message>
        <source>Global:</source>
        <translation>Global:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>V:</source>
        <translation>V:</translation>
    </message>
    <message>
        <source>Maintain:</source>
        <translation>Preservar:</translation>
    </message>
    <message>
        <source>Shear</source>
        <translation>Inclinación</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="vanished">Centro</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation type="vanished">Bloquear</translation>
    </message>
    <message>
        <source>(</source>
        <translation>(</translation>
    </message>
    <message>
        <source>)</source>
        <translation>)</translation>
    </message>
    <message>
        <source>Center Position</source>
        <translation>Posición del centro</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Posición:</translation>
    </message>
    <message>
        <source>Rotation:</source>
        <translation>Rotación:</translation>
    </message>
    <message>
        <source>Table</source>
        <translation>Mesa</translation>
    </message>
    <message>
        <source>Flip Object Horizontally</source>
        <translatorcomment>Invertir objeto horizontalmente</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <source>Flip Object Vertically</source>
        <translation>Invertir objeto verticalmente</translation>
    </message>
    <message>
        <source>Rotate Object Left</source>
        <translation>Rotar objeto en sentido antihorario</translation>
    </message>
    <message>
        <source>Rotate Object Right</source>
        <translation>Rotar objeto en sentido horario</translation>
    </message>
</context>
<context>
    <name>BrushTool</name>
    <message>
        <source>Thickness</source>
        <translation type="vanished">Grosor</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation type="vanished">Dureza:</translation>
    </message>
    <message>
        <source>Accuracy:</source>
        <translation type="vanished">Precisión:</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation type="vanished">Selectivo</translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation type="vanished">Ajustes:</translation>
    </message>
    <message>
        <source>Break Sharp Angles</source>
        <translation type="vanished">Quebrar ángulos agudos</translation>
    </message>
    <message>
        <source>Pencil Mode</source>
        <translation type="vanished">Modo lápiz</translation>
    </message>
    <message>
        <source>Pressure Sensitivity</source>
        <translation type="vanished">Sensibilidad a presión</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation type="vanished">Extremos</translation>
    </message>
    <message>
        <source>Join</source>
        <translation type="vanished">Esquinas</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation type="vanished">Inglete:</translation>
    </message>
    <message>
        <source>Size</source>
        <translation type="vanished">Tamaño</translation>
    </message>
    <message>
        <source>Break</source>
        <translation type="vanished">Quebrar</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation type="vanished">Lápiz</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation type="vanished">Presión</translation>
    </message>
    <message>
        <source>Smooth:</source>
        <translation type="vanished">Estabilidad:</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation type="vanished">Rango:</translation>
    </message>
    <message>
        <source>Snap</source>
        <translation type="vanished">Adherencia</translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation type="vanished">&lt;personalizado&gt;</translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="vanished">no</translation>
    </message>
    <message>
        <source>Linear</source>
        <translation type="vanished">Lineal</translation>
    </message>
    <message>
        <source>In</source>
        <translation type="vanished">Desacelerado</translation>
    </message>
    <message>
        <source>Out</source>
        <translation type="vanished">Acelerado</translation>
    </message>
    <message>
        <source>In&amp;Out</source>
        <translation type="vanished">Ambos</translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="vanished">Baja</translation>
    </message>
    <message>
        <source>High</source>
        <translation type="vanished">Alta</translation>
    </message>
    <message>
        <source>Butt cap</source>
        <translation type="vanished">Rectos</translation>
    </message>
    <message>
        <source>Round cap</source>
        <translation type="vanished">Redondeados</translation>
    </message>
    <message>
        <source>Projecting cap</source>
        <translation type="vanished">Proyectantes</translation>
    </message>
    <message>
        <source>Miter join</source>
        <translation type="vanished">En inglete</translation>
    </message>
    <message>
        <source>Round join</source>
        <translation type="vanished">Redondeadas</translation>
    </message>
    <message>
        <source>Bevel join</source>
        <translation type="vanished">Biseladas</translation>
    </message>
    <message>
        <source>Med</source>
        <translation type="vanished">Media</translation>
    </message>
    <message>
        <source>Draw Order:</source>
        <translation type="vanished">Orden:</translation>
    </message>
    <message>
        <source>Over All</source>
        <translation type="vanished">Por encima</translation>
    </message>
    <message>
        <source>Under All</source>
        <translation type="vanished">Por debajo</translation>
    </message>
    <message>
        <source>Palette Order</source>
        <translation type="vanished">Según paleta</translation>
    </message>
</context>
<context>
    <name>BrushToolOptionsBox</name>
    <message>
        <source>Preset Name</source>
        <translation>Nombre del ajuste</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>ControlPointEditorTool</name>
    <message>
        <source>Auto Select Drawing</source>
        <translation>Seleccionar dibujo automáticamente</translation>
    </message>
    <message>
        <source>Snap</source>
        <translation>Adherencia</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>Marco</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>Lazo</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Baja</translation>
    </message>
    <message>
        <source>Med</source>
        <translation>Media</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Alta</translation>
    </message>
</context>
<context>
    <name>ControlPointSelection</name>
    <message>
        <source>Set Linear Control Point</source>
        <translation>Punto de control Lineal</translation>
    </message>
    <message>
        <source>Set Nonlinear Control Point</source>
        <translation>Punto de control Bezier</translation>
    </message>
</context>
<context>
    <name>DVGui::StyleIndexLineEdit</name>
    <message>
        <source>current</source>
        <translation>actual</translation>
    </message>
</context>
<context>
    <name>EditTool</name>
    <message>
        <source>Scale Constraint:</source>
        <translation>Restringir escala:</translation>
    </message>
    <message>
        <source>Auto Select Column</source>
        <translation>Seleccionar columna automáticamente</translation>
    </message>
    <message>
        <source>Global Key</source>
        <translation>Clave global</translation>
    </message>
    <message>
        <source>Lock Center X</source>
        <translation>Bloquear centro X</translation>
    </message>
    <message>
        <source>Lock Center Y</source>
        <translation>Bloquear centro Y</translation>
    </message>
    <message>
        <source>Lock Position X</source>
        <translation>Bloquear posición X</translation>
    </message>
    <message>
        <source>Lock Position Y</source>
        <translation>Bloquear posición Y</translation>
    </message>
    <message>
        <source>Lock Rotation</source>
        <translation>Bloquear rotación</translation>
    </message>
    <message>
        <source>Lock Shear H</source>
        <translation>Bloquear inclinación H</translation>
    </message>
    <message>
        <source>Lock Shear V</source>
        <translation>Bloquear inclinación V</translation>
    </message>
    <message>
        <source>Lock Scale H</source>
        <translation>Bloquear escala H</translation>
    </message>
    <message>
        <source>Lock Scale V</source>
        <translation>Bloquear escala V</translation>
    </message>
    <message>
        <source>Lock Global Scale</source>
        <translation>Bloquear escala global</translation>
    </message>
    <message>
        <source>X and Y Positions</source>
        <translation>Posiciones X e Y</translation>
    </message>
    <message>
        <source>Z Position</source>
        <translation>Posición Z</translation>
    </message>
    <message>
        <source>SO</source>
        <translation>Orden</translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation>Rotación</translation>
    </message>
    <message>
        <source>Global Scale</source>
        <translation>Escala global</translation>
    </message>
    <message>
        <source>Horizontal and Vertical Scale</source>
        <translation>Escala horizontal y vertical</translation>
    </message>
    <message>
        <source>Shear</source>
        <translation>Inclinación</translation>
    </message>
    <message>
        <source>Center Position</source>
        <translation>Posición centro</translation>
    </message>
    <message>
        <source>Active Axis</source>
        <translation>Eje activo</translation>
    </message>
    <message>
        <source>None</source>
        <translation>nada</translation>
    </message>
    <message>
        <source>A/R</source>
        <translation>Proporción</translation>
    </message>
    <message>
        <source>Mass</source>
        <translation>Masa</translation>
    </message>
    <message>
        <source>Column</source>
        <translation>Columnas</translation>
    </message>
    <message>
        <source>Pegbar</source>
        <translation>Barras de sujeción</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Posición</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Escala</translation>
    </message>
    <message>
        <source>Center</source>
        <translation>Centro</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Todo</translation>
    </message>
</context>
<context>
    <name>EraserTool</name>
    <message>
        <source>Size:</source>
        <translation>Tamaño:</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>Dureza:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>Modo:</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>Selectivo</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertir</translation>
    </message>
    <message>
        <source>Frame Range</source>
        <translation>Rango de fotogramas</translation>
    </message>
    <message>
        <source>Pencil Mode</source>
        <translation>Lápiz</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>Marco</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>Lazo</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>Línea poligonal</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>Líneas</translation>
    </message>
    <message>
        <source>Areas</source>
        <translation>Áreas</translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation>Líneas y áreas</translation>
    </message>
    <message>
        <source>Segment</source>
        <translation>Segmento</translation>
    </message>
    <message>
        <source>Linear</source>
        <translation>Lineal</translation>
    </message>
    <message>
        <source>Ease In</source>
        <translation>Desaceleración suave</translation>
    </message>
    <message>
        <source>Ease Out</source>
        <translation>Aceleración suave</translation>
    </message>
    <message>
        <source>Ease In/Out</source>
        <translation>Aceleración y desaceleración suaves</translation>
    </message>
</context>
<context>
    <name>FillTool</name>
    <message>
        <source>Frame Range</source>
        <translation>Rango de fotogramas</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>Selectivo</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>Modo:</translation>
    </message>
    <message>
        <source>Onion Skin</source>
        <translation>Piel de cebolla</translation>
    </message>
    <message>
        <source>Fill Depth</source>
        <translation>Profundidad</translation>
    </message>
    <message>
        <source>Segment</source>
        <translation>Segmento</translation>
    </message>
    <message>
        <source>Autopaint Lines</source>
        <translation>Pintar líneas automáticamente</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>Marco</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>Lazo</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>Línea poligonal</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>Líneas</translation>
    </message>
    <message>
        <source>Areas</source>
        <translation>Áreas</translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation>Líneas y áreas</translation>
    </message>
    <message>
        <source>Maximum Gap</source>
        <translation>Hueco máximo</translation>
    </message>
    <message>
        <source>Pick+Freehand</source>
        <translation>Escoger+Lazo</translation>
    </message>
</context>
<context>
    <name>FingerTool</name>
    <message>
        <source>Size:</source>
        <translation>Tamaño:</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertir</translation>
    </message>
</context>
<context>
    <name>FullColorBrushTool</name>
    <message>
        <source>Thickness</source>
        <translation type="vanished">Grosor</translation>
    </message>
    <message>
        <source>Pressure Sensitivity</source>
        <translation type="vanished">Sensibilidad a presión</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation type="vanished">Opacidad:</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>Dureza:</translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation>Ajustes:</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>Presión</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Opacidad</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>Borrador</translation>
    </message>
    <message>
        <source>Lock Alpha</source>
        <translation>Preservar alfa</translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation>&lt;personalizado&gt;</translation>
    </message>
</context>
<context>
    <name>FullColorEraserTool</name>
    <message>
        <source>Size:</source>
        <translation>Tamaño:</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Opacidad:</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>Dureza:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertir</translation>
    </message>
    <message>
        <source>Frame Range</source>
        <translation>Rango de fotogramas</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>Marco</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>Lazo</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>Línea poligonal</translation>
    </message>
</context>
<context>
    <name>FullColorFillTool</name>
    <message>
        <source>Fill Depth</source>
        <translation>Profundidad</translation>
    </message>
</context>
<context>
    <name>HandToolOptionsBox</name>
    <message>
        <source>Reset Position</source>
        <translation>Restablecer posición</translation>
    </message>
</context>
<context>
    <name>HookTool</name>
    <message>
        <source>Snap</source>
        <translation>Adherencia</translation>
    </message>
</context>
<context>
    <name>MagnetTool</name>
    <message>
        <source>Size:</source>
        <translation>Tamaño:</translation>
    </message>
</context>
<context>
    <name>PaintBrushTool</name>
    <message>
        <source>Size:</source>
        <translation>Tamaño:</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>Modo:</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>Selectivo</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>Líneas</translation>
    </message>
    <message>
        <source>Areas</source>
        <translation>Áreas</translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation>Líneas y áreas</translation>
    </message>
    <message>
        <source>Lock Alpha</source>
        <translation>Preservar alfa</translation>
    </message>
</context>
<context>
    <name>PinchTool</name>
    <message>
        <source>Size:</source>
        <translation>Tamaño:</translation>
    </message>
    <message>
        <source>Corner:</source>
        <translation>Ángulo:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
</context>
<context>
    <name>PlasticTool</name>
    <message>
        <source>Build Skeleton</source>
        <translation>Crear esqueleto</translation>
    </message>
    <message>
        <source>Paint Rigid</source>
        <translation>Pintar rigidez</translation>
    </message>
    <message>
        <source>Animate</source>
        <translation>Animar</translation>
    </message>
    <message>
        <source>Rigid</source>
        <translation>Rígido</translation>
    </message>
    <message>
        <source>Flex</source>
        <translation>Flexible</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>Modo:</translation>
    </message>
    <message>
        <source>Vertex Name:</source>
        <translation>Nombre del vértice:</translation>
    </message>
    <message>
        <source>Allow Stretching</source>
        <translation>Permitir estiramiento</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>Grosor</translation>
    </message>
    <message>
        <source>Keep Distance</source>
        <translation>Mantener distancia</translation>
    </message>
    <message>
        <source>Global Key</source>
        <translation>Clave global</translation>
    </message>
    <message>
        <source>A group of skeletons already exists for current column. Replacing it will also substitute any existing vertex animation.

Do you want to continue?</source>
        <translation>Ya existe un grupo de esqueletos para la columna actual. Reemplazarlo también sustituirá cualquier animación de vértices existente.

¿Desea continuar?</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Copy Skeleton</source>
        <translation>Copiar esqueleto</translation>
    </message>
    <message>
        <source>Paste Skeleton</source>
        <translation>Pegar esqueleto</translation>
    </message>
    <message>
        <source>Delete Vertex</source>
        <translation>Borrar vértice</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>Marcar clave</translation>
    </message>
    <message>
        <source>Set Rest Key</source>
        <translation>Marcar clave (en reposo)</translation>
    </message>
    <message>
        <source>Show Mesh</source>
        <translation>Mostrar malla</translation>
    </message>
    <message>
        <source>Show Rigidity</source>
        <translation>Mostrar rigidez</translation>
    </message>
    <message>
        <source>Show SO</source>
        <translation>Mostrar orden</translation>
    </message>
    <message>
        <source>Show Skeleton Onion Skin</source>
        <translation>Mostrar piel de cebolla del esqueleto</translation>
    </message>
    <message>
        <source>The previous vertex name will be discarded, and all associated keys will be lost.

Do you want to proceed?</source>
        <translation>Se descartará el nombre anterior del vértice, y se perderán todos los claves asociados al mismo.

¿Desea continuar?</translation>
    </message>
    <message>
        <source>Set Global Key</source>
        <translation>Marcar clave global</translation>
    </message>
    <message>
        <source>Set Global Rest Key</source>
        <translation>Marcar clave global (en reposo)</translation>
    </message>
    <message>
        <source>Edit Mesh</source>
        <translation>Editar malla</translation>
    </message>
    <message>
        <source>Snap To Mesh</source>
        <translation>Adherir a la malla</translation>
    </message>
    <message>
        <source>Angle Bounds</source>
        <translation>Límites de ángulo</translation>
    </message>
    <message>
        <source>Swap Edge</source>
        <translation>Rotar borde</translation>
    </message>
    <message>
        <source>Collapse Edge</source>
        <translation>Colapsar borde</translation>
    </message>
    <message>
        <source>Split Edge</source>
        <translation>Dividir borde</translation>
    </message>
    <message>
        <source>Cut Mesh</source>
        <translation>Cortar malla</translation>
    </message>
</context>
<context>
    <name>PlasticToolOptionsBox</name>
    <message>
        <source>Create Mesh</source>
        <translation>Crear malla</translation>
    </message>
    <message>
        <source>Skeleton:</source>
        <translation>Esqueleto:</translation>
    </message>
    <message>
        <source>SO</source>
        <translation>Orden</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>Ángulo</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>Distancia</translation>
    </message>
</context>
<context>
    <name>PrimitiveParam</name>
    <message>
        <source>Shape:</source>
        <translation>Forma:</translation>
    </message>
    <message>
        <source>Thickness:</source>
        <translation>Grosor:</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Opacidad:</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>Dureza:</translation>
    </message>
    <message>
        <source>Polygon Sides:</source>
        <translation>Lados:</translation>
    </message>
    <message>
        <source>Auto Group</source>
        <translation>Agrupar automáticamente</translation>
    </message>
    <message>
        <source>Auto Fill</source>
        <translation>Rellenar automáticamente</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>Selectivo</translation>
    </message>
    <message>
        <source>Pencil Mode</source>
        <translation>Lápiz</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation>Extremos</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>Esquinas</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation>Inglete:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Tamaño:</translation>
    </message>
    <message>
        <source>Snap</source>
        <translation>Adherencia</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectángulo</translation>
    </message>
    <message>
        <source>Circle</source>
        <translation>Círculo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Línea</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>Curva Bezier</translation>
    </message>
    <message>
        <source>Arc</source>
        <translation>Arco</translation>
    </message>
    <message>
        <source>Polygon</source>
        <translation>Polígono</translation>
    </message>
    <message>
        <source>Butt cap</source>
        <translation>Rectos</translation>
    </message>
    <message>
        <source>Round cap</source>
        <translation>Redondeados</translation>
    </message>
    <message>
        <source>Projecting cap</source>
        <translation>Proyectantes</translation>
    </message>
    <message>
        <source>Miter join</source>
        <translation>En inglete</translation>
    </message>
    <message>
        <source>Round join</source>
        <translation>Redondeadas</translation>
    </message>
    <message>
        <source>Bevel join</source>
        <translation>Biseladas</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Baja</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <source>Med</source>
        <translation>Media</translation>
    </message>
    <message>
        <source>MultiArc</source>
        <translation>Arco múltiple</translation>
    </message>
    <message>
        <source>Smooth</source>
        <translation>Suavizar</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Rotar</translation>
    </message>
</context>
<context>
    <name>PumpTool</name>
    <message>
        <source>Size:</source>
        <translation>Tamaño:</translation>
    </message>
    <message>
        <source>Accuracy:</source>
        <translation>Precisión:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Min:</source>
        <translation>Mín:</translation>
    </message>
    <message>
        <source>Max:</source>
        <translation>Máx:</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <source>The copied selection cannot be pasted in the current drawing.</source>
        <translation>La selección copiada no puede ser pegada en el dibujo actual.</translation>
    </message>
    <message>
        <source>The current column is locked.</source>
        <translation>La columna actual está bloqueada.</translation>
    </message>
    <message>
        <source>The current column is not visible in Camera Stand.</source>
        <translation type="vanished">La columna actual no se encuentra visible en la vista de mesa de trabajo.</translation>
    </message>
    <message>
        <source>It is not possible to edit the audio column.</source>
        <translation>No es posible editar la columna de audio.</translation>
    </message>
    <message>
        <source>It is not possible to edit the Magpie column.</source>
        <translation type="vanished">No es posible editar la columna de Magpie.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Level column.</source>
        <translation>No es posible usar la herramienta actual en una columna de nivel.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Mesh column.</source>
        <translation>No es posible usar la herramienta actual en una columna de malla.</translation>
    </message>
    <message>
        <source>The current tool cannot be used in Level Strip mode.</source>
        <translation>No es posible usar la herramienta actual en la cinta de nivel.</translation>
    </message>
    <message>
        <source>The current tool cannot be used to edit a motion path.</source>
        <translation>No es posible usar la herramienta actual para editar una trayectoria de movimiento.</translation>
    </message>
    <message>
        <source>The current level is not editable.</source>
        <translation>El nivel actual no es editable.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Vector Level.</source>
        <translation>No es posible usar la herramienta actual en un nivel vectorial.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Toonz Level.</source>
        <translation>No es posible usar la herramienta actual en un nivel de imagen de Toonz.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Raster Level.</source>
        <translation>No es posible usar la herramienta actual en un nivel de imagen.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Mesh Level.</source>
        <translation>No es posible usar la herramienta actual en un nivel de malla.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a mesh-deformed level</source>
        <translation>No es posible usar la herramienta actual en un nivel de malla deformada.</translation>
    </message>
    <message>
        <source>The current frame is locked: any editing is forbidden.</source>
        <translation>El fotograma actual está bloqueado: no se permite su edición.</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
    <message>
        <source>Move Center</source>
        <translation>Mover centro</translation>
    </message>
    <message>
        <source>RGB Picker (R%1, G%2, B%3)</source>
        <translation>Selector RVA (R%1, V%2, A%3)</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Agrupar</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation>Desagrupar</translation>
    </message>
    <message>
        <source>Move Group</source>
        <translation>Mover grupo</translation>
    </message>
    <message>
        <source>Modify Fx Gadget  </source>
        <translation>Control de modificación de efectos</translation>
    </message>
    <message>
        <source>%1   Level : %2  Frame : %3</source>
        <translation>%1   Nivel : %2  Fotograma : %3</translation>
    </message>
    <message>
        <source>Modify Stroke Tool</source>
        <translation>Modificar trazo</translation>
    </message>
    <message>
        <source>Modify Spline</source>
        <translation>Modificar curva</translation>
    </message>
    <message>
        <source>Deform Raster</source>
        <translation>Deformar imagen</translation>
    </message>
    <message>
        <source>Transform Raster</source>
        <translation>Transformar imagen</translation>
    </message>
    <message>
        <source>Set Save Box : (X%1,Y%2,W%3,H%4)-&gt;(X%5,Y%6,W%7,H%8)</source>
        <translation>Definir marco delimitador : (X%1,Y%2,An%3,Al%4)-&gt;(X%5,Y%6,An%7,Al%8)</translation>
    </message>
    <message>
        <source>The current column is hidden.</source>
        <translation>La columna actual está oculta.</translation>
    </message>
    <message>
        <source>Note columns can only be edited in the xsheet or timeline.</source>
        <translation>Las columnas de notas sólo pueden ser editadas en la planilla o la línea de tiempo.</translation>
    </message>
    <message>
        <source> to Front</source>
        <translation> al frente</translation>
    </message>
    <message>
        <source> to Forward</source>
        <translation> hacia adelante</translation>
    </message>
    <message>
        <source> to Back</source>
        <translation> al fondo</translation>
    </message>
    <message>
        <source> to Backward</source>
        <translation> hacia atrás</translation>
    </message>
    <message>
        <source>The selection cannot be updated. It is not editable.</source>
        <translation>La selección no puede ser actualizada. No es editable.</translation>
    </message>
    <message>
        <source>The selection cannot be deleted. It is not editable.</source>
        <translation>La selección no puede ser borrada. No es editable.</translation>
    </message>
    <message>
        <source>The selection cannot be pasted. It is not editable.</source>
        <translation>La selección no puede ser pegada. No es editable.</translation>
    </message>
    <message>
        <source>The selection cannot be grouped. It is not editable.</source>
        <translation>La selección no puede ser agrupada. No es editable.</translation>
    </message>
    <message>
        <source>The selection cannot be entered. It is not editable.</source>
        <translation>No es posible entrar a la selección. No es editable.</translation>
    </message>
    <message>
        <source>The selection cannot be ungrouped. It is not editable.</source>
        <translation>La selección no puede ser desagrupada. No es editable.</translation>
    </message>
    <message>
        <source>The selection cannot be moved. It is not editable.</source>
        <translation>La selección no puede ser movida. No es editable.</translation>
    </message>
    <message>
        <source>Snap At Intersection</source>
        <translation>Adherir a intersecciones</translation>
    </message>
</context>
<context>
    <name>RGBPickerTool</name>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Passive Pick</source>
        <translation>Selección pasiva</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>Marco</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>Lazo</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>Línea poligonal</translation>
    </message>
</context>
<context>
    <name>RGBPickerToolOptionsBox</name>
    <message>
        <source>Pick Screen</source>
        <translation>Seleccionar desde la pantalla</translation>
    </message>
</context>
<context>
    <name>RasterSelectionTool</name>
    <message>
        <source>Modify Savebox</source>
        <translation>Editar marco delimitador</translation>
    </message>
    <message>
        <source>No Antialiasing</source>
        <translation>Sin suavizado de bordes</translation>
    </message>
</context>
<context>
    <name>RasterTapeTool</name>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Distance:</source>
        <translation>Distancia:</translation>
    </message>
    <message>
        <source>Style Index:</source>
        <translation>Identificador del estilo:</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Opacidad:</translation>
    </message>
    <message>
        <source>Frame Range</source>
        <translation>Rango de fotogramas</translation>
    </message>
    <message>
        <source>Angle:</source>
        <translation>Ángulo:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>Marco</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>Lazo</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>Línea poligonal</translation>
    </message>
    <message>
        <source>current</source>
        <translation>actual</translation>
    </message>
</context>
<context>
    <name>RotateTool</name>
    <message>
        <source>Rotate On Camera Center</source>
        <translation>Rotar en torno al centro de la cámara</translation>
    </message>
</context>
<context>
    <name>RotateToolOptionsBox</name>
    <message>
        <source>Reset Rotation</source>
        <translation>Restablecer rotación</translation>
    </message>
</context>
<context>
    <name>RulerToolOptionsBox</name>
    <message>
        <source>X:</source>
        <comment>ruler tool option</comment>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <comment>ruler tool option</comment>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <comment>ruler tool option</comment>
        <translation>Ancho:</translation>
    </message>
    <message>
        <source>H:</source>
        <comment>ruler tool option</comment>
        <translation>Altura:</translation>
    </message>
    <message>
        <source>A:</source>
        <comment>ruler tool option</comment>
        <translation>Ángulo:</translation>
    </message>
    <message>
        <source>L:</source>
        <comment>ruler tool option</comment>
        <translation>Longitud:</translation>
    </message>
</context>
<context>
    <name>SelectionTool</name>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>Marco</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>Lazo</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>Línea poligonal</translation>
    </message>
</context>
<context>
    <name>SelectionToolOptionsBox</name>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>V:</source>
        <translation>V:</translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation>Rotación</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>Grosor</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Vincular</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Escala</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Posición</translation>
    </message>
    <message>
        <source>Flip Selection Horizontally</source>
        <translation>Invertir selección horizontalmente</translation>
    </message>
    <message>
        <source>Flip Selection Vertically</source>
        <translation>Invertir selección verticalmente</translation>
    </message>
    <message>
        <source>Rotate Selection Left</source>
        <translation>Rotar selección en sentido antihorario</translation>
    </message>
    <message>
        <source>Rotate Selection Right</source>
        <translation>Rotar selección en sentido horario</translation>
    </message>
</context>
<context>
    <name>ShiftTraceToolOptionBox</name>
    <message>
        <source>Reset Previous</source>
        <translation>Restablecer anterior</translation>
    </message>
    <message>
        <source>Reset Following</source>
        <translation>Restablecer siguiente</translation>
    </message>
    <message>
        <source>Previous Drawing</source>
        <translation>Dibujo anterior</translation>
    </message>
    <message>
        <source>Following Drawing</source>
        <translation>Dibujo siguiente</translation>
    </message>
</context>
<context>
    <name>SkeletonTool</name>
    <message>
        <source>Show Only Active Skeleton</source>
        <translation>Mostrar sólo esqueleto activo</translation>
    </message>
    <message>
        <source>Global Key</source>
        <translation>Clave global</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>Modo:</translation>
    </message>
    <message>
        <source>Reset Pinned Center</source>
        <translation>Restablecer centro fijo</translation>
    </message>
    <message>
        <source>Build Skeleton</source>
        <translation>Crear esqueleto</translation>
    </message>
    <message>
        <source>Animate</source>
        <translation>Animar</translation>
    </message>
    <message>
        <source>Inverse Kinematics</source>
        <translation>Cinemática inversa</translation>
    </message>
</context>
<context>
    <name>StylePickerTool</name>
    <message>
        <source>No current level.</source>
        <translation>No hay nivel actual.</translation>
    </message>
    <message>
        <source>Current level has no available palette.</source>
        <translation>El nivel actual no tiene una paleta disponible.</translation>
    </message>
    <message>
        <source>Palette must have more than one palette to be organized.</source>
        <translation>Es necesario que exista más de una paleta para poder organizarlas.</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>Modo:</translation>
    </message>
    <message>
        <source>Passive Pick</source>
        <translation>Selección pasiva</translation>
    </message>
    <message>
        <source>Organize Palette</source>
        <translation>Organizar paleta</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>Líneas</translation>
    </message>
    <message>
        <source>Areas</source>
        <translation>Áreas</translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation>Líneas y áreas</translation>
    </message>
</context>
<context>
    <name>StylePickerToolOptionsBox</name>
    <message>
        <source>With this option being activated, the picked style will be
moved to the end of the first page of the palette.</source>
        <translation>Con esta opción activa, el estilo escogido será
movido hacia el final de la primera página de la paleta.</translation>
    </message>
</context>
<context>
    <name>ToonzRasterBrushTool</name>
    <message>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>Dureza:</translation>
    </message>
    <message>
        <source>Smooth:</source>
        <translation>Estabilidad:</translation>
    </message>
    <message>
        <source>Draw Order:</source>
        <translation>Orden:</translation>
    </message>
    <message>
        <source>Over All</source>
        <translation>Por encima</translation>
    </message>
    <message>
        <source>Under All</source>
        <translation>Por debajo</translation>
    </message>
    <message>
        <source>Palette Order</source>
        <translation>Según paleta</translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation>Ajustes:</translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation>&lt;personalizado&gt;</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Lápiz</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>Presión</translation>
    </message>
    <message>
        <source>Lock Alpha</source>
        <translation>Preservar alfa</translation>
    </message>
</context>
<context>
    <name>ToonzVectorBrushTool</name>
    <message>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <source>Accuracy:</source>
        <translation>Precisión:</translation>
    </message>
    <message>
        <source>Smooth:</source>
        <translation>Estabilidad:</translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation>Ajustes:</translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation>&lt;personalizado&gt;</translation>
    </message>
    <message>
        <source>Break</source>
        <translation>Quebrar</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>Presión</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation>Extremos</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>Esquinas</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation>Inglete:</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Rango:</translation>
    </message>
    <message>
        <source>Snap</source>
        <translation>Adherencia</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>no</translation>
    </message>
    <message>
        <source>Linear</source>
        <translation>Lineal</translation>
    </message>
    <message>
        <source>In</source>
        <translation>Desacelerado</translation>
    </message>
    <message>
        <source>Out</source>
        <translation>Acelerado</translation>
    </message>
    <message>
        <source>In&amp;Out</source>
        <translation>Ambos</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Baja</translation>
    </message>
    <message>
        <source>Med</source>
        <translation>Media</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <source>Butt cap</source>
        <translation>Rectos</translation>
    </message>
    <message>
        <source>Round cap</source>
        <translation>Redondeados</translation>
    </message>
    <message>
        <source>Projecting cap</source>
        <translation>Proyectantes</translation>
    </message>
    <message>
        <source>Miter join</source>
        <translation>En inglete</translation>
    </message>
    <message>
        <source>Round join</source>
        <translation>Redondeadas</translation>
    </message>
    <message>
        <source>Bevel join</source>
        <translation>Biseladas</translation>
    </message>
</context>
<context>
    <name>TrackerTool</name>
    <message>
        <source>Width:</source>
        <translation>Ancho:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Altura:</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
</context>
<context>
    <name>TypeTool</name>
    <message>
        <source>Font:</source>
        <translation>Tipografía:</translation>
    </message>
    <message>
        <source>Style:</source>
        <translation>Estilo:</translation>
    </message>
    <message>
        <source>Vertical Orientation</source>
        <translation>Orientación vertical</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Tamaño:</translation>
    </message>
</context>
<context>
    <name>VectorSelectionTool</name>
    <message>
        <source>Mode:</source>
        <translation>Modo:</translation>
    </message>
    <message>
        <source>Preserve Thickness</source>
        <translation>Preservar grosor</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation>Extremos</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>Esquinas</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation>Inglete:</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>Estándar</translation>
    </message>
    <message>
        <source>Selected Frames</source>
        <translation>Fotogramas seleccionados</translation>
    </message>
    <message>
        <source>Whole Level</source>
        <translation>Todo el nivel</translation>
    </message>
    <message>
        <source>Same Style</source>
        <translation>Mismo estilo</translation>
    </message>
    <message>
        <source>Same Style on Selected Frames</source>
        <translation>M. estilo en fot. seleccionados</translation>
    </message>
    <message>
        <source>Same Style on Whole Level</source>
        <translation>M. estilo en todo el nivel</translation>
    </message>
    <message>
        <source>Boundary Strokes</source>
        <translation>Trazos limítrofes</translation>
    </message>
    <message>
        <source>Boundaries on Selected Frames</source>
        <translation>T. limítrofes en fot. seleccionados</translation>
    </message>
    <message>
        <source>Boundaries on Whole Level</source>
        <translation>T. limítrofes en todo el nivel</translation>
    </message>
    <message>
        <source>Butt cap</source>
        <translation>Rectos</translation>
    </message>
    <message>
        <source>Round cap</source>
        <translation>Redondeados</translation>
    </message>
    <message>
        <source>Projecting cap</source>
        <translation>Proyectantes</translation>
    </message>
    <message>
        <source>Miter join</source>
        <translation>En inglete</translation>
    </message>
    <message>
        <source>Round join</source>
        <translation>Redondeadas</translation>
    </message>
    <message>
        <source>Bevel join</source>
        <translation>Biseladas</translation>
    </message>
    <message>
        <source>Include Intersection</source>
        <translation>Incluir intersección</translation>
    </message>
</context>
<context>
    <name>VectorTapeTool</name>
    <message>
        <source>Smooth</source>
        <translation>Suavizar</translation>
    </message>
    <message>
        <source>Join Vectors</source>
        <translation>Unir vectores</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>Distancia</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>Modo:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Endpoint to Endpoint</source>
        <translation>Extremo a extremo</translation>
    </message>
    <message>
        <source>Endpoint to Line</source>
        <translation>Extremo a línea</translation>
    </message>
    <message>
        <source>Line to Line</source>
        <translation>Línea a línea</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>Marco</translation>
    </message>
</context>
<context>
    <name>ZoomToolOptionsBox</name>
    <message>
        <source>Reset Zoom</source>
        <translation>Restablecer zoom</translation>
    </message>
</context>
</TS>
